local ldb = LibStub:GetLibrary("LibDataBroker-1.1");
local Toolkit = LibStub:GetLibrary("Toolkit-1.0");

local dataObject = ldb:NewDataObject("HealPoints", {
		type = "launcher",
		icon = "Interface\\Icons\\Spell_Holy_FlashHeal",
		label = "HealPoints",
		OnClick = function(clickedframe, button)
				if (button == "RightButton") then
					InterfaceOptionsFrame_OpenToCategory(HealPoints.options)					 
				else
					HealPoints:ToggleCalculator();
				end
			end
});

function dataObject:OnTooltipShow()
	self:AddLine("|cffffffffHealPoints|r"); --|cffffcc00|r

	local currentStats = HealPointsCalculator:GetCurrentHealPoints();
	local iv, sv, spv, scrv, shrv, powerfulSpell, efficientSpell = HealPointsCalculator:ComputeHealPointsDelta(currentStats);

	local function spellToString(spell)
		if (spell == nil) then
			return "none";
		else	
			return HealPointsSpells:GetSpellLink(spell, false)
--			local spellName = GetSpellInfo(spell.id);
			--return spellName;
		end
	end

	self:AddDoubleLine("Heal Points:", HIGHLIGHT_FONT_COLOR_CODE..Toolkit:IntToStrLocale(currentStats.healPoints)..FONT_COLOR_CODE_CLOSE);
	self:AddDoubleLine("Power Points ("..spellToString(powerfulSpell)..")", HIGHLIGHT_FONT_COLOR_CODE..Toolkit:IntToStrLocale(currentStats.powerPoints)..FONT_COLOR_CODE_CLOSE);
	self:AddDoubleLine("Endurance Points ("..spellToString(efficientSpell)..")", HIGHLIGHT_FONT_COLOR_CODE..Toolkit:IntToStrLocale(currentStats.endurancePoints)..FONT_COLOR_CODE_CLOSE);
	--self:AddLine(" ");
	--self:AddDoubleLine("Powerful Spell:", spellToString(powerfulSpell));
	--self:AddDoubleLine("Endurance Spell:", spellToString(efficientSpell));

	local minRel = math.min(iv, sv, spv, scrv, shrv);
	local maxRel = math.max(iv, sv, spv, scrv, shrv);

	assert(minRel);
	assert(maxRel);

	local function getStatText(hpFromStat)
		assert(hpFromStat);
		local s = Toolkit:RangeColorText(
				string.format("%.2f", hpFromStat),
				hpFromStat,
				minRel, HIGHLIGHT_FONT_COLOR.r, HIGHLIGHT_FONT_COLOR.g, HIGHLIGHT_FONT_COLOR.b, 
				maxRel, GREEN_FONT_COLOR.r, GREEN_FONT_COLOR.g, GREEN_FONT_COLOR.b)--]]
--		local s = HIGHLIGHT_FONT_COLOR_CODE..string.format("%.1f", hpFromStat)..FONT_COLOR_CODE_CLOSE;
		return s;
	end;

	self:AddLine(" ");
	self:AddDoubleLine("Relative Stat Values", "HealPoints", 
			HIGHLIGHT_FONT_COLOR.r, HIGHLIGHT_FONT_COLOR.g, HIGHLIGHT_FONT_COLOR.b,
			HIGHLIGHT_FONT_COLOR.r, HIGHLIGHT_FONT_COLOR.g, HIGHLIGHT_FONT_COLOR.b);
	self:AddDoubleLine("1.00 Intellect:", getStatText(iv));
	self:AddDoubleLine("1.00 Spirit:", getStatText(sv));
	self:AddDoubleLine("1.00 Spell Power:", getStatText(spv));
	self:AddDoubleLine("1.00 Crit Rating:", getStatText(scrv));
	self:AddDoubleLine("1.00 Haste Rating:", getStatText(shrv));
	

	self:AddLine(" ");
	self:AddLine("|cffffff00Hint: Click to toggle the calculator window"..FONT_COLOR_CODE_CLOSE);
	self:AddLine("|cffffff00Right-click to open the options menu"..FONT_COLOR_CODE_CLOSE)

end;

local stats = { };

stats[1] = { stat = "Intellect",    statmod = 1 };
stats[2] = { stat = "Spirit",       statmod = 1 };
stats[3] = { stat = "Spell power",  statmod = 1 };
stats[4] = { stat = "Crit rating",  statmod = 1 };
stats[5] = { stat = "Haste rating", statmod = 1 };

function HealPoints:PrintMVS()
	local function statTableSort(e1, e2)
		if (e1.value > e2.value) then
			return true;
		else
			return false;
		end
	end

--	if HealPoints.ISHEALER then
		local currentStats = HealPointsCalculator:GetCurrentHealPoints();
		local iv, sv, spv, scrv, shrv, powerfulSpell, efficientSpell = HealPointsCalculator:ComputeHealPointsDelta(currentStats);

	--end

	stats[1].value = iv; --Intellect
	stats[2].value = sv; --Spirit
	stats[3].value = spv; --Spell Power
	stats[4].value = scrv; --Spell Crit Rating
	stats[5].value = shrv; --Spell Haste Rating
	table.sort(stats, statTableSort);
	

	self:Print("Most valuable stat ranking:");
	self:Print("--------------------------------------");
	for i = 1, table.getn(stats) do
		self:Print(string.format("1.00 %s: %.2f heal points", stats[i].stat, stats[i].value));
	end
end

local options = {
	name = "HealPoints",
	desc = "HealPoints Configuration.",
	type = "group",
	args = {
		calc = {
			type = "execute",
			name = "Calculator",
			desc = "Display the HealPoints calculator",
			order = 9,
			func = function()
				HealPoints:ToggleCalculator();
			end,
		},
			
		tooltips ={
			type = "toggle",
			name = "Values in tooltips",
			desc = "Toggles the display of HealPoints change in item tooltips.",
			order = 10,
			get = function()
				return HealPoints.db.char.tooltips == 1;
			end,
			set = function()
				HealPoints.db.char.tooltips = 1 - HealPoints.db.char.tooltips;
			end
		},
		debug ={
			type = "toggle",
			name = "Debug mode",
			desc = "Toggles the display of debug messages.",
			order = 11,
			get = function()
				return HealPoints.db.char.debug == 1;
			end,
			set = function()
				HealPoints:ClearCache();
				HealPoints.db.char.debug = 1 - HealPoints.db.char.debug;
			end
		},

		mvs ={
			type = "execute",
			name = "Most valuable stats",
			desc = "Lists the most valuable stat ranking according to current gear and buffs.",
			order = 20,
			func = function()
				HealPoints:PrintMVS();
			end,
		},
--[[
		bscan ={
			type = "execute",
			name = "Special item bonuses",
			desc = "Print special set/equip bonuses detected to the console.",
			order = 21,
			func = function()
				HealPoints:listScannedBonuses();
			end
		},--]]

		gemheader = {
			type = "header",
			name = "Gem selector",			
			desc = "",
			order = 30,
			cmdHidden = true,
		},		
		bluegems ={
			type = "select",
			name = "Blue Sockets",
			desc = "Select gem to be used for empty blue socket calculations.",
			order = 31,
			cmdHidden = true,
			width = "full",
			get = function() 
				return HealPoints.db.char.gems.blueGem;
			end,
			set = function(t, v)
				HealPoints:ClearCache();
				HealPoints.db.char.gems.blueGem = v;
			end,
			values = HealPointsGems.blueSocket,
		},
		redgems ={
			type = "select",
			name = "Red Sockets",
			desc = "Select gem to be used for empty red socket calculations.",
			order = 32,
			cmdHidden = true,
			width = "full",
			get = function() 
				return HealPoints.db.char.gems.redGem;
			end,
			set = function(t, v)
				HealPoints:ClearCache();
				HealPoints.db.char.gems.redGem = v;
			end,
			values = HealPointsGems.redSocket,
		},
		yellowgems ={
			type = "select",
			name = "Yellow Sockets",
			desc = "Select gem to be used for empty yellow socket calculations.",
			order = 33,
			cmdHidden = true,
			width = "full",
			get = function() 
				return HealPoints.db.char.gems.yellowGem;
			end,
			set = function(t, v)
				HealPoints:ClearCache();
				HealPoints.db.char.gems.yellowGem = v;
			end,
			values = HealPointsGems.yellowSocket,
		},
	},
};

LibStub("AceConfig-3.0"):RegisterOptionsTable("HealPoints", options, "healpoints");
LibStub("AceConfigRegistry-3.0"):RegisterOptionsTable("HealPoints", options);
HealPoints.options = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("HealPoints", "HealPoints");
