
HealPointsUtil = { };

function HealPointsUtil:colorValue(value)
	value = value or 0;
	local v = format("%5.0f", value);
	if (value == 0) then
		return v;
	elseif (value > 0) then
		return GREEN_FONT_COLOR_CODE..v..FONT_COLOR_CODE_CLOSE;
	else
		return RED_FONT_COLOR_CODE..v..FONT_COLOR_CODE_CLOSE;
	end
end

function HealPointsUtil:getTableIndex(t, entry)
  for i = 1, table.getn(t), 1 do
    if (t[i] == entry) then
      return i;
    end
  end
end

function HealPointsUtil:round(num)
  return math.floor((num or 0) + 0.5);
end

function HealPointsUtil:isPlayerBuffUp(buffName)
  local iIterator = 1
  while (UnitBuff("player", iIterator)) do
    if (string.find(UnitBuff("player", iIterator), buffName)) then
      return true
    end
    iIterator = iIterator + 1
  end
  return false
end;

--[[
	Returns a player's "Base Mana".
	Your base mana is the amount of mana you are left with if you took away all intellect (hence
	took away all mana from intellect)
	@returns A number containing the player's base mana
	@example local baseMana = HealPointsUtil.getBaseMana();
--]]
function HealPointsUtil:GetBaseMana()
  local _, intellect, _, _ = UnitStat("player", 4);
  
  --[[BUG: Doesn't yet take into account other mana increasing effects, e.g.
		- Druid Furor talent
		- Arcane Brilliance buff
		- Beaming Earthsiege Diamond
		- 
  --]]
  return UnitManaMax("player") - (math.min(20, intellect) + 15 * (intellect - math.min(20, intellect))); 
end

--[[
	Returns the basic "Combat Regen" (how much mana is regenerated while in combat.
	While mana regen is usually quoted a "mana per 5 seconds", this return value
	is mana per second
--]]
function HealPointsUtil:GetBaseCombatManaRegen()
	--[[
		A player's basic Combat Regen is 5% of their base mana.
		e.g. a paladin with 24,732 mana, with 1,310 mana from intellect leaves 23,422 "base mana"
			5% of 23,422 = 1,171
		Which matches exactly my "Combat Regen" of 1171 in the tooltip.
	--]]
	local baseMana = HealPointsUtil:GetBaseMana();
	return baseMana*0.05 / 5; --divide by 5 to get per-second
end

function HealPointsUtil:GetManaFromInt(intellect)
	return intellect*15; --Yes, 15 mana per point of intellect
end;

function HealPointsUtil:GetSpellPowerFromInt(intellect)
	return intellect; --Yes, 1 int gives 1 spell power
end;